==> webgui_7.9.18.orig.tar.gz: WebGUI/lib/WebGUI/i18n/Dutch/Asset_StoryTopic.pm <==
package WebGUI::i18n::Dutch::Asset_StoryTopic;
use utf8;
our $I18N = {
  'Read more stories' => {
    'lastUpdated' => '1253797594',
    'message' => 'Lees meer verhalen'
  },
  'assetName' => {
    'lastUpdated' => '1256137326',
    'message' => 'Verhaal op onderwerp'
  },
  'atomUrl' => {
    'lastUpdated' => '1248783067',
    'message' => 'De Atom URL van dit verhalen archief.'
  },
  'creationDate' => {
    'lastUpdated' => '1248182238',
    'message' => 'De epoch tijd waarop dit verhaal is aangemaakt of ingevoerd.'
  },
  'deleteIcon' => {
    'lastUpdated' => '1248783085',
    'message' => 'Een ikoon om dit verhaal te verwijderen. Als de gebruiker het verhaal
niet mag verwijderen, of als hun gebruikersinterfaceniveau te laag is
zal deze variabele geen inhoud hebben.'
  },
  'editIcon' => {
    'lastUpdated' => '1248783091',
    'message' => 'Een ikoon om dit verhaal te bewerken. Als de gebruiker het verhaal niet mag bewerken, of als hun
gebruikersinterfaceniveau te laag is zal deze variabele geen inhoud
hebben.'
  },
  'rssUrl' => {
    'lastUpdated' => '1248783096',
    'message' => 'De URL van de RSS van dit verhalen archief.'
  },
  'standAlone' => {
    'lastUpdated' => '1248182820',
    'message' => 'Deze variabele is waar als het onderwerp direct bekeken wordt via de URL. Anders, als het via een pagina layout of een andere containrer bekeken wordt, zal deze onwaar zijn.'
  },
  'stories per topic' => {
    'lastUpdated' => '1248182837',
    'message' => 'Verhalen per onderwerp'
  },
  'stories per topic help' => {
    'lastUpdated' => '1248182901',
    'message' => 'Het aantal verhalen dat in RSS en Atom getoond wordt via dit verhaalonderwerp en wanneer het onderwerp direct bekeken wordt.'
  },
  'stories short' => {
    'lastUpdated' => '1248182919',
    'message' => 'Verhalen per pagina'
  },
  'stories short help' => {
    'lastUpdated' => '1248182993',
    'message' => 'Het aantal verhalen dat op een pagina getoond wordt.'
  },
  'story template' => {
    'lastUpdated' => '1248183008',
    'message' => 'Verhaal sjabloon'
  },
  'story template help' => {
    'lastUpdated' => '1248183044',
    'message' => 'Het sjabloon dat gebruikt wordt voor het tonen van verhalen met dit onderwerp.'
  },
  'story_loop' => {
    'lastUpdated' => '1248183072',
    'message' => 'Een functie die de meest recente verhalen met dit onderwerp ophaalt.'
  },
  'storytopic asset template variables title' => {
    'lastUpdated' => '1248183106',
    'message' => 'Verhaal onderwerp asset sjabloonvariabelen'
  },
  'template' => {
    'lastUpdated' => '1248182958',
    'message' => 'Hoofd sjabloon'
  },
  'template help' => {
    'lastUpdated' => '1248184221',
    'message' => 'Het sjabloon waarmee dit verhalen onderwerp getoond wordt.'
  },
  'title' => {
    'lastUpdated' => '1248182939',
    'message' => 'De titel van een verhaal'
  },
  'topStoryCreationDate' => {
    'lastUpdated' => '1248184758',
    'message' => 'De epoch tijd waarop het bovenste verhaal is gemaakt of ingevoerd aan het verhalen archief.'
  },
  'topStoryImageAlt' => {
    'lastUpdated' => '1248184716',
    'message' => 'De alternatieve tekst van de eerste foto van het bovenste verhaal, als deze bestaat.'
  },
  'topStoryImageByline' => {
    'lastUpdated' => '1248184691',
    'message' => 'De regel met de auteur van de eerste foto van het bovenste verhaal, als deze bestaat.'
  },
  'topStoryImageCaption' => {
    'lastUpdated' => '1248184660',
    'message' => 'Het onderschrift van de eerste foto van het bovenste verhaal, als deze bestaat.'
  },
  'topStoryImageLink' => {
    'lastUpdated' => '1248184632',
    'message' => 'De link naar de eerste foto van het bovenste verhaal als deze bestaat.'
  },
  'topStoryImageTitle' => {
    'lastUpdated' => '1248184607',
    'message' => 'De titel van de afbeelding van het bovenste verhaal als deze bestaat'
  },
  'topStoryImageUrl' => {
    'lastUpdated' => '1248184579',
    'message' => 'De URL van de eerste foto van het bovenste verhaal, als deze bestaat.'
  },
  'topStorySubtitle' => {
    'lastUpdated' => '1248184554',
    'message' => 'De ondertitel van het bovenste verhaal.'
  },
  'topStoryTitle' => {
    'lastUpdated' => '1248184525',
    'message' => 'De titel van het bovenste verhaal'
  },
  'topStoryUrl' => {
    'lastUpdated' => '1248184513',
    'message' => 'Het URL om het bovenste verhaal te bekijken.'
  },
  'url' => {
    'lastUpdated' => '1248184385',
    'message' => 'Het URL om een verhaal te bekijken.'
  },
  'view template' => {
    'lastUpdated' => '1248184400',
    'message' => 'Bekijk onderwerp sjabloon'
  }
}
;

1;

==> webgui_7.10.28.orig.tar.gz: WebGUI/lib/WebGUI/i18n/Dutch/Asset_StoryTopic.pm <==
package WebGUI::i18n::Dutch::Asset_StoryTopic;
use utf8;
our $I18N = {
  'Read more stories' => {
    'lastUpdated' => '1253797594',
    'message' => 'Lees meer verhalen'
  },
  'assetName' => {
    'lastUpdated' => '1256137326',
    'message' => 'Verhaal op onderwerp'
  },
  'atomUrl' => {
    'lastUpdated' => '1248783067',
    'message' => 'De Atom URL van dit verhalen archief.'
  },
  'creationDate' => {
    'lastUpdated' => '1248182238',
    'message' => 'De epoch tijd waarop dit verhaal is aangemaakt of ingevoerd.'
  },
  'deleteIcon' => {
    'lastUpdated' => '1248783085',
    'message' => 'Een ikoon om dit verhaal te verwijderen. Als de gebruiker het verhaal
niet mag verwijderen, of als hun gebruikersinterfaceniveau te laag is
zal deze variabele geen inhoud hebben.'
  },
  'editIcon' => {
    'lastUpdated' => '1248783091',
    'message' => 'Een ikoon om dit verhaal te bewerken. Als de gebruiker het verhaal niet mag bewerken, of als hun
gebruikersinterfaceniveau te laag is zal deze variabele geen inhoud
hebben.'
  },
  'rssUrl' => {
    'lastUpdated' => '1248783096',
    'message' => 'De URL van de RSS van dit verhalen archief.'
  },
  'standAlone' => {
    'lastUpdated' => '1248182820',
    'message' => 'Deze variabele is waar als het onderwerp direct bekeken wordt via de URL. Anders, als het via een pagina layout of een andere containrer bekeken wordt, zal deze onwaar zijn.'
  },
  'stories per topic' => {
    'lastUpdated' => '1248182837',
    'message' => 'Verhalen per onderwerp'
  },
  'stories per topic help' => {
    'lastUpdated' => '1248182901',
    'message' => 'Het aantal verhalen dat in RSS en Atom getoond wordt via dit verhaalonderwerp en wanneer het onderwerp direct bekeken wordt.'
  },
  'stories short' => {
    'lastUpdated' => '1248182919',
    'message' => 'Verhalen per pagina'
  },
  'stories short help' => {
    'lastUpdated' => '1248182993',
    'message' => 'Het aantal verhalen dat op een pagina getoond wordt.'
  },
  'story template' => {
    'lastUpdated' => '1248183008',
    'message' => 'Verhaal sjabloon'
  },
  'story template help' => {
    'lastUpdated' => '1248183044',
    'message' => 'Het sjabloon dat gebruikt wordt voor het tonen van verhalen met dit onderwerp.'
  },
  'story_loop' => {
    'lastUpdated' => '1297774575',
    'message' => 'Een functie die de meest recente verhalen met dit onderwerp ophaalt. Alle verhaal sjabloonvariabelen zijn hier ook beschikbaar.'
  },
  'storytopic asset template variables title' => {
    'lastUpdated' => '1248183106',
    'message' => 'Verhaal onderwerp asset sjabloonvariabelen'
  },
  'template' => {
    'lastUpdated' => '1248182958',
    'message' => 'Hoofd sjabloon'
  },
  'template help' => {
    'lastUpdated' => '1248184221',
    'message' => 'Het sjabloon waarmee dit verhalen onderwerp getoond wordt.'
  },
  'title' => {
    'lastUpdated' => '1248182939',
    'message' => 'De titel van een verhaal'
  },
  'topStory' => {
    'lastUpdated' => '1297774704',
    'message' => 'Een variabele met dezelfde soort waarden als de strory_loop, maar voor het bovenste verhaal. Toegangelijk via topStory.hasPhotos e.d.'
  },
  'topStoryCreationDate' => {
    'lastUpdated' => '1248184758',
    'message' => 'De epoch tijd waarop het bovenste verhaal is gemaakt of ingevoerd aan het verhalen archief.'
  },
  'topStoryImageAlt' => {
    'lastUpdated' => '1248184716',
    'message' => 'De alternatieve tekst van de eerste foto van het bovenste verhaal, als deze bestaat.'
  },
  'topStoryImageByline' => {
    'lastUpdated' => '1248184691',
    'message' => 'De regel met de auteur van de eerste foto van het bovenste verhaal, als deze bestaat.'
  },
  'topStoryImageCaption' => {
    'lastUpdated' => '1248184660',
    'message' => 'Het onderschrift van de eerste foto van het bovenste verhaal, als deze bestaat.'
  },
  'topStoryImageLink' => {
    'lastUpdated' => '1248184632',
    'message' => 'De link naar de eerste foto van het bovenste verhaal als deze bestaat.'
  },
  'topStoryImageTitle' => {
    'lastUpdated' => '1248184607',
    'message' => 'De titel van de afbeelding van het bovenste verhaal als deze bestaat'
  },
  'topStoryImageUrl' => {
    'lastUpdated' => '1248184579',
    'message' => 'De URL van de eerste foto van het bovenste verhaal, als deze bestaat.'
  },
  'topStorySubtitle' => {
    'lastUpdated' => '1248184554',
    'message' => 'De ondertitel van het bovenste verhaal.'
  },
  'topStoryTitle' => {
    'lastUpdated' => '1248184525',
    'message' => 'De titel van het bovenste verhaal'
  },
  'topStoryUrl' => {
    'lastUpdated' => '1248184513',
    'message' => 'Het URL om het bovenste verhaal te bekijken.'
  },
  'url' => {
    'lastUpdated' => '1248184385',
    'message' => 'Het URL om een verhaal te bekijken.'
  },
  'view template' => {
    'lastUpdated' => '1248184400',
    'message' => 'Bekijk onderwerp sjabloon'
  }
}
;

1;
